@@ -1,6 +1,6 @@
 #include <cmath>
 
-#include "include/StaticImageProperties.h"
+#include "StaticImageProperties.h"
 
 void yk::ColorizeDepthImage(const k4a::image &depthImage,
                              DepthPixelVisualizationFunction visualizationFn,
